@@ -1,4 +1,5 @@
-from flask import _app_ctx_stack
+from threading import get_ident
+
 from sqlalchemy import engine, orm
 from sqlalchemy.orm.exc import UnmappedClassError
 
@@ -24,13 +25,7 @@ class SQLAlchemyDB(object):
     '''
 
     def __init__(self, db_connection, base_model, session_options=None, **kwargs):
-
-        if isinstance(db_connection, str):
-            self.engine = engine.create_engine(db_connection, convert_unicode=True, **kwargs)
-            self.connection = self.engine.connect()
-        else:
-            self.connection = db_connection
-
+        self.engine = engine.create_engine(db_connection, convert_unicode=True, **kwargs)
         self.Query = orm.Query
         self.session = self.create_scoped_session(session_options)
         self.Model = self.extend_base_model(base_model)
@@ -50,17 +45,16 @@ class SQLAlchemyDB(object):
 
         options = options or {}
 
-        scopefunc = _app_ctx_stack.__ident_func__
         options.setdefault('query_cls', self.Query)
 
         return orm.scoped_session(
-            self.create_session(options), scopefunc=scopefunc)
+            self.create_session(options), scopefunc=get_ident)
 
     def create_session(self, options):
-        return orm.sessionmaker(bind=self.connection, **options)
+        return orm.sessionmaker(bind=self.engine, **options)
 
     def create_all_tables(self):
-        self.metadata.create_all(bind=self.connection)
+        self.metadata.create_all(bind=self.engine)
 
     def init_app(self, app):
         @app.teardown_appcontext
